/*
 * Copyright 2009 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.gradle.api;

import org.gradle.api.internal.Contextual;

/**
 * <p>A <code>GradleScriptException</code> is thrown when an exception occurs in the compilation or execution of a
 * script.</p>
 *
 * @author Hans Dockter
 */
@Contextual
public class GradleScriptException extends GradleException {
    public GradleScriptException(String message, Throwable cause) {
        super(message, cause);
    }
}
